#!/usr/local/perl/bin/perl -w

# Acronym - Adds acronym tags to known acronyms.
# "This is a XHTML test" becomes "This is a <acronym title="Extensible HyperText Markup Language">XHTML</acronym> test"
# Henrik Gemal - http://gemal.dk/mt/acronym.html
# If you modify this code please let me know and I'll try to incorporate the changes into Acronym

use strict;
use warnings;

my($MT_DIR);
BEGIN {
	if ($0 =~ m!(.*[/\\])!) {
		$MT_DIR = $1;
	} else {
		$MT_DIR = './';
	}
	unshift @INC, $MT_DIR . 'lib';
	unshift @INC, $MT_DIR . 'extlib';
}

package MTApp::Acronym;

use vars qw($VERSION $DEBUG);
$VERSION = "2.1";
$DEBUG = 0;

@::MTApp::Acronym::ISA = qw(MT::App::CMS);
use MT::App::CMS;
use MT::ConfigMgr;

sub uri {
	$_[0]->path . ($_[0]->{author} ? MT::ConfigMgr->instance->AdminScript : $_[0]->script);
}

sub init {
	my $app = shift;
	$app->SUPER::init (@_) or return;
	$app->add_methods (
			default	=> \&default,
			mnu	=> \&default,
	);
	$app->{default_mode} = 'default';
	$app->{requires_login} = 1;
	$app->{user_class} = 'MT::Author';
  $app->{is_admin} = 1;
	$app;
}

sub acronym_debug {
	my($txt) = @_;
	print STDERR "MTAcronym: $txt\n" if ($DEBUG);
}

sub default {
	my ($app, $html, $parent, $child) = @_;
	my %param = (func_default => 1, version => $VERSION);

	my %ACRONYM;
	if (my $acronym_plugin = MT::ConfigMgr->instance->PluginPath) {
		$acronym_plugin .= "/acronym.db";
		if (-f $acronym_plugin) {
			acronym_debug("Loading <$acronym_plugin>");
			open(FILE, $acronym_plugin) or die "Cannot open file <$acronym_plugin> ($!)";
			%ACRONYM = map { chomp; (split /:/) } <FILE>;
			close FILE;
			$param{acronymdb} = $acronym_plugin;
		} else {
			$param{error} = "Acronym database file not found at <$acronym_plugin>";
		}
	} else {
		acronym_debug("Unable to get PluginPath");
		$param{error} = "Unable to get PluginPath from MT::ConfigMgr";
	}

	my @acronyms;
	foreach my $data (sort keys %ACRONYM) {
		push @acronyms, {acronym => $data, description => $ACRONYM{$data}};
	}
	$param{acronyms} = \@acronyms;
	$param{count} = scalar @acronyms;

	$app->add_breadcrumb($app->translate('Acronym'));
	$app->build_page('acronym.tmpl', \%param);
}

eval {
	my $app = MTApp::Acronym->new(Config => $MT_DIR . 'mt.cfg', Directory => $MT_DIR ) or die MTApp::Acronym->errstr;
	local $SIG{__WARN__} = sub {$app->trace ($_[0])};
	$app->run;
};

if ($@) {
	print "Content-Type: text/html\n\n";
	print "An error occurred: $@";
}
